import 'package:flutter/material.dart';

import 'constants.dart';

enum RButtonType {
  normal,
  twoLine,
  address,
}

class RButton extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _RButton();
  }

  final String title;
  final String subtitle;
  final Function onPress;
  final RButtonType type;
  final bool extended;
  final Icon icon;
  final Color color;
  final Color titleColor;
  final bool isTransparent;
  final double elevation;
  RButton(
    this.title,
    this.onPress, {
    this.subtitle,
    this.type = RButtonType.normal,
    this.color = Colors.transparent,
    this.titleColor = Colors.black87,
    this.extended = true,
    this.isTransparent = false,
    this.icon,
    this.elevation = 2,
  });
}

class _RButton extends State<RButton> {
  @override
  Widget build(BuildContext context) {
    return Container(
      width: this.widget.extended ? double.infinity : null,
      child: RaisedButton(
        elevation: this.widget.elevation,
        padding: EdgeInsets.symmetric(vertical: 2),
        shape: RoundedRectangleBorder(
          borderRadius: new BorderRadius.circular(5),
        ),
        color:
            this.widget.isTransparent || this.widget.color != Colors.transparent
                ? this.widget.color
                : AppColors.green,
        child: _getChild(this.widget.type),
        onPressed: this.widget.onPress,
      ),
    );
  }

  Widget _getChild(RButtonType _type) {
    if (_type == RButtonType.address)
      return Row(
        children: <Widget>[
          Padding(
            padding: EdgeInsets.symmetric(horizontal: 16),
            child: this.widget.icon,
          ),
          Text(
            this.widget.title,
            style: TextStyle(
              color: this.widget.titleColor ?? Colors.black26,
              fontSize: 14,
            ),
          ),
        ],
      );
    else if (_type == RButtonType.twoLine)
      return Column(
        children: <Widget>[
          Text(
            this.widget.title,
            style: TextStyle(
              color: Colors.white,
              fontSize: 16,
            ),
          ),
          Text(
            this.widget.subtitle,
            style: TextStyle(
              color: Colors.white,
              fontSize: 16,
            ),
          ),
        ],
      );
    else
      return Text(
        this.widget.title,
        style: TextStyle(
          fontWeight: FontWeight.bold,
          fontSize: 18,
          color: this.widget.isTransparent ||
                  this.widget.color != Colors.transparent
              ? this.widget.titleColor ?? Colors.black87
              : Colors.white,
        ),
      );
  }
}
