import 'package:flutter/material.dart';
import 'rlc_text.dart';

class RListItem extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _RListItem();
  }

  Widget titleWidget;
  Widget subtitleWidget;
  final title;
  final subtitle;
  final Widget leading;
  final Widget trailing;
  final Alignment trailingAlign;
  final Widget topItem;
  final Widget bottomItem;
  final Function onPress;
  final Color color;
  final Color titleColor;
  final Color subtitleColor;
  final double elevation;
  RListItem(
    this.title, {
    this.leading,
    this.trailing,
    this.trailingAlign,
    this.topItem,
    this.bottomItem,
    this.onPress,
    this.subtitle,
    this.color,
    this.titleColor = Colors.black87,
    this.subtitleColor = Colors.black54,
    this.elevation,
  }) {
    titleWidget = _setTitle();
    subtitleWidget = subtitle == null ? null : _setSubtitle();
  }

  Widget _setTitle() {
    if (title is String)
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          RText(
            title,
            isBold: true,
            size: RTextSize.medium,
          )
        ],
      );
    else if (title is List<String>)
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: title
            .map<Widget>((x) => RText(
                  title,
                  isBold: true,
                  size: RTextSize.medium,
                ))
            .toList(),
      );
    else if (title is Widget)
      return title;
    else
      return null;
  }

  Widget _setSubtitle() {
    if (subtitle is String)
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          RText(
            subtitle,
            color: RTextColor.lightBlack,
          )
        ],
      );
    else if (subtitle is List<String>)
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: subtitle
            .map<Widget>((x) => RText(
                  x,
                  color: RTextColor.lightBlack,
                ))
            .toList(),
      );
    else if (subtitle is Widget)
      return subtitle;
    else
      return null;
  }
}

class _RListItem extends State<RListItem> {
  @override
  Widget build(BuildContext context) {
    return FlatButton(
      onPressed: this.widget.onPress ?? () => {},
      padding: EdgeInsets.zero,
      child: Card(
        elevation: this.widget.elevation ?? 0,
        margin: EdgeInsets.symmetric(vertical: 5),
        shape: RoundedRectangleBorder(
            side: BorderSide(
              width: 1,
              color: this.widget.color ?? Colors.black26,
            ),
            borderRadius: BorderRadius.all(Radius.circular(5))),
        child: Column(
          children: <Widget>[
            this.widget.topItem ?? Container(),
            Padding(
              padding: const EdgeInsets.all(10),
              child: Row(children: <Widget>[
                this.widget.leading != null
                    ? Container(
                        padding: EdgeInsets.only(right: 20),
                        child: this.widget.leading,
                      )
                    : Container(),
                Expanded(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      widget.titleWidget,
                      widget.subtitleWidget,
                    ],
                  ),
                ),
                this.widget.trailing != null
                    ? Container(
                        alignment:
                            this.widget.trailingAlign ?? Alignment.center,
                        padding: EdgeInsets.only(left: 10),
                        child: this.widget.trailing,
                      )
                    : Container(),
              ]),
            ),
            this.widget.bottomItem ?? Container(),
          ],
        ),
      ),
    );
  }
}
