import 'package:flutter/material.dart';

class RTextSize {
  const RTextSize._(this.index);

  final int index;
  static const RTextSize smallest = RTextSize._(0);
  static const RTextSize small = RTextSize._(1);
  static const RTextSize medium = RTextSize._(2);
  static const RTextSize large = RTextSize._(3);
  static const RTextSize xLarge = RTextSize._(4);
  static const RTextSize xxLarge = RTextSize._(5);
  static const RTextSize normal = small;
  static const List<RTextSize> values = <RTextSize>[
    smallest,
    small,
    medium,
    large,
    xLarge,
    xxLarge
  ];

  double getValue() {
    return const <int, double>{
      0: 11,
      1: 12,
      2: 14,
      3: 16,
      4: 20,
      5: 24,
    }[index];
  }
}

class RTextColor {
  const RTextColor._(this.index);

  final int index;
  static const RTextColor green = RTextColor._(0);
  static const RTextColor white = RTextColor._(1);
  static const RTextColor black = RTextColor._(2);
  static const RTextColor lightBlack = RTextColor._(3);
  static const RTextColor veryLightBlack = RTextColor._(4);
  static const RTextColor red = RTextColor._(5);
  static const RTextColor normal = black;
  static const List<RTextColor> values = <RTextColor>[
    green,
    white,
    black,
    lightBlack,
    veryLightBlack,
    red,
  ];

  RTextColor({this.index});

  Color customColor(Color value) {
    return value;
  }

  Color getValue() {
    return const <int, Color>{
      0: Color(0xff0fa510),
      1: Colors.white,
      2: Colors.black87,
      3: Colors.black54,
      4: Colors.black26,
      5: Colors.red,
    }[index];
  }
}

class RTextAlign {
  const RTextAlign._(this.index);

  final int index;
  static const RTextAlign start = RTextAlign._(0);
  static const RTextAlign center = RTextAlign._(1);
  static const RTextAlign end = RTextAlign._(2);

  MainAxisAlignment getValue() {
    return const <int, MainAxisAlignment>{
      0: MainAxisAlignment.start,
      1: MainAxisAlignment.center,
      2: MainAxisAlignment.end,
    }[index];
  }
}

class RText extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _RText();
  }

  final String text;
  final RTextColor color;
  final Color customColor;
  final bool isBold;
  final RTextSize size;
  final double margin;
  final RTextAlign textAlign;
  RText(
    this.text, {
    this.color = RTextColor.normal,
    this.customColor,
    this.isBold,
    this.size = RTextSize.normal,
    this.margin,
    this.textAlign = RTextAlign.start,
  });
}

class _RText extends State<RText> {
  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.symmetric(vertical: this.widget.margin ?? 2),
      child: Row(
        mainAxisAlignment: widget.textAlign.getValue(),
        // mainAxisSize: MainAxisSize.min,
        children: <Widget>[
          Flexible(
            fit: FlexFit.loose,
            child: Text(
              this.widget.text,
              style: TextStyle(
                color: this.widget.customColor ?? this.widget.color.getValue(),
                fontWeight: this.widget.isBold != null && this.widget.isBold
                    ? FontWeight.bold
                    : FontWeight.normal,
                fontSize: this.widget.size.getValue() ?? 12,
              ),
            ),
          ),
        ],
      ),
    );
  }
}
